@@ -24,34 +24,27 @@ options:
   server:
     description:
       - IRC server name/address
-    required: false
     default: localhost
   port:
     description:
       - IRC server port number
-    required: false
     default: 6667
   nick:
     description:
       - Nickname to send the message from. May be shortened, depending on server's NICKLEN setting.
-    required: false
     default: ansible
   msg:
     description:
       - The message body.
     required: true
-    default: null
   topic:
     description:
       - Set the channel topic
-    required: false
-    default: null
     version_added: "2.0"
   color:
     description:
       - Text color for the message. ("none" is a valid option in 1.6 or later, in 1.6 and prior, the default color is black, not "none").
         Added 11 more colors in version 2.0.
-    required: false
     default: "none"
     choices: [ "none", "white", "black", "blue", "green", "red", "brown", "purple", "orange", "yellow", "light_green", "teal", "light_cyan",
                "light_blue", "pink", "gray", "light_gray"]
@@ -62,18 +55,14 @@ options:
   nick_to:
     description:
       - A list of nicknames to send the message to. One of nick_to or channel needs to be set.  When both are defined, the message will be sent to both of them.
-    required: false
-    default: null
     version_added: "2.0"
   key:
     description:
       - Channel key
-    required: false
     version_added: "1.7"
   passwd:
     description:
       - Server password
-    required: false
   timeout:
     description:
       - Timeout to use while waiting for successful registration and join
@@ -83,19 +72,19 @@ options:
   use_ssl:
     description:
       - Designates whether TLS/SSL should be used when connecting to the IRC server
-    default: False
+    type: bool
+    default: 'no'
     version_added: "1.8"
   part:
     description:
       - Designates whether user should part from channel after sending message or not.
         Useful for when using a faux bot and not wanting join/parts between messages.
-    default: True
+    type: bool
+    default: 'yes'
     version_added: "2.0"
   style:
     description:
       - Text style for the message. Note italic does not work on some clients
-    default: None
-    required: False
     choices: [ "bold", "underline", "reverse", "italic" ]
     version_added: "2.0"
 
@@ -144,13 +133,14 @@ import ssl
 import time
 import traceback
 
+from ansible.module_utils._text import to_native, to_bytes
 from ansible.module_utils.basic import AnsibleModule
-from ansible.module_utils._text import to_native
 
 
-def send_msg(msg, server='localhost', port='6667', channel=None, nick_to=[], key=None, topic=None,
+def send_msg(msg, server='localhost', port='6667', channel=None, nick_to=None, key=None, topic=None,
              nick="ansible", color='none', passwd=False, timeout=30, use_ssl=False, part=True, style=None):
     '''send message to IRC'''
+    nick_to = [] if nick_to is None else nick_to
 
     colornumbers = {
         'white': "00",
@@ -180,13 +170,13 @@ def send_msg(msg, server='localhost', port='6667', channel=None, nick_to=[], key
 
     try:
         styletext = stylechoices[style]
-    except:
+    except Exception:
         styletext = ""
 
     try:
         colornumber = colornumbers[color]
         colortext = "\x03" + colornumber
-    except:
+    except Exception:
         colortext = ""
 
     message = styletext + colortext + msg
@@ -195,17 +185,18 @@ def send_msg(msg, server='localhost', port='6667', channel=None, nick_to=[], key
     if use_ssl:
         irc = ssl.wrap_socket(irc)
     irc.connect((server, int(port)))
+
     if passwd:
-        irc.send('PASS %s\r\n' % passwd)
-    irc.send('NICK %s\r\n' % nick)
-    irc.send('USER %s %s %s :ansible IRC\r\n' % (nick, nick, nick))
+        irc.send(to_bytes('PASS %s\r\n' % passwd))
+    irc.send(to_bytes('NICK %s\r\n' % nick))
+    irc.send(to_bytes('USER %s %s %s :ansible IRC\r\n' % (nick, nick, nick)))
     motd = ''
     start = time.time()
     while 1:
-        motd += irc.recv(1024)
+        motd += to_native(irc.recv(1024))
         # The server might send back a shorter nick than we specified (due to NICKLEN),
         #  so grab that and use it from now on (assuming we find the 00[1-4] response).
-        match = re.search('^:\S+ 00[1-4] (?P<nick>\S+) :', motd, flags=re.M)
+        match = re.search(r'^:\S+ 00[1-4] (?P<nick>\S+) :', motd, flags=re.M)
         if match:
             nick = match.group('nick')
             break
@@ -214,33 +205,33 @@ def send_msg(msg, server='localhost', port='6667', channel=None, nick_to=[], key
         time.sleep(0.5)
 
     if key:
-        irc.send('JOIN %s %s\r\n' % (channel, key))
+        irc.send(to_bytes('JOIN %s %s\r\n' % (channel, key)))
     else:
-        irc.send('JOIN %s\r\n' % channel)
+        irc.send(to_bytes('JOIN %s\r\n' % channel))
 
     join = ''
     start = time.time()
     while 1:
-        join += irc.recv(1024)
-        if re.search('^:\S+ 366 %s %s :' % (nick, channel), join, flags=re.M):
+        join += to_native(irc.recv(1024))
+        if re.search(r'^:\S+ 366 %s %s :' % (nick, channel), join, flags=re.M):
             break
         elif time.time() - start > timeout:
             raise Exception('Timeout waiting for IRC JOIN response')
         time.sleep(0.5)
 
     if topic is not None:
-        irc.send('TOPIC %s :%s\r\n' % (channel, topic))
+        irc.send(to_bytes('TOPIC %s :%s\r\n' % (channel, topic)))
         time.sleep(1)
 
     if nick_to:
         for nick in nick_to:
-            irc.send('PRIVMSG %s :%s\r\n' % (nick, message))
+            irc.send(to_bytes('PRIVMSG %s :%s\r\n' % (nick, message)))
     if channel:
-        irc.send('PRIVMSG %s :%s\r\n' % (channel, message))
+        irc.send(to_bytes('PRIVMSG %s :%s\r\n' % (channel, message)))
     time.sleep(1)
     if part:
-        irc.send('PART %s\r\n' % channel)
-        irc.send('QUIT\r\n')
+        irc.send(to_bytes('PART %s\r\n' % channel))
+        irc.send(to_bytes('QUIT\r\n'))
         time.sleep(1)
     irc.close()
 
@@ -258,11 +249,11 @@ def main():
             nick_to=dict(required=False, type='list'),
             msg=dict(required=True),
             color=dict(default="none", aliases=['colour'], choices=["white", "black", "blue",
-                                                "green", "red", "brown",
-                                                "purple", "orange", "yellow",
-                                                "light_green", "teal", "light_cyan",
-                                                "light_blue", "pink", "gray",
-                                                "light_gray", "none"]),
+                                                                    "green", "red", "brown",
+                                                                    "purple", "orange", "yellow",
+                                                                    "light_green", "teal", "light_cyan",
+                                                                    "light_blue", "pink", "gray",
+                                                                    "light_gray", "none"]),
             style=dict(default="none", choices=["underline", "reverse", "bold", "italic", "none"]),
             channel=dict(required=False),
             key=dict(no_log=True),
