@@ -32,7 +32,6 @@ options:
   path:
     description:
       - Alternate path to the authorized_keys file
-    required: false
     default: "(homedir)+/.ssh/authorized_keys"
     version_added: "1.2"
   manage_dir:
@@ -43,21 +42,17 @@ options:
         set C(manage_dir=no) if you are using an alternate directory for
         authorized_keys, as set with C(path), since you could lock yourself out of
         SSH access. See the example below.
-    required: false
-    choices: [ "yes", "no" ]
-    default: "yes"
+    type: bool
+    default: 'yes'
     version_added: "1.2"
   state:
     description:
       - Whether the given key (with the given key_options) should or should not be in the file
-    required: false
     choices: [ "present", "absent" ]
     default: "present"
   key_options:
     description:
       - A string of ssh key options to be prepended to the key in the authorized_keys file
-    required: false
-    default: null
     version_added: "1.4"
   exclusive:
     description:
@@ -66,38 +61,40 @@ options:
       - This option is not loop aware, so if you use C(with_) , it will be exclusive per iteration
         of the loop, if you want multiple keys in the file you need to pass them all to C(key) in a
         single batch as mentioned above.
-    required: false
-    choices: [ "yes", "no" ]
-    default: "no"
+    type: bool
+    default: 'no'
     version_added: "1.9"
   validate_certs:
     description:
       - This only applies if using a https url as the source of the keys. If set to C(no), the SSL certificates will not be validated.
       - This should only set to C(no) used on personally controlled sites using self-signed certificates as it avoids verifying the source site.
       - Prior to 2.1 the code worked as if this was set to C(yes).
-    required: false
-    default: "yes"
-    choices: ["yes", "no"]
+    type: bool
+    default: 'yes'
     version_added: "2.1"
   comment:
     description:
       - Change the comment on the public key. Rewriting the comment is useful in
         cases such as fetching it from GitHub or GitLab.
       - If no comment is specified, the existing comment will be kept.
-    required: false
-    default: None
     version_added: "2.4"
+  follow:
+    description:
+      - Follow path symlink instead of replacing it
+    type: bool
+    default: 'no'
+    version_added: "2.7"
 author: "Ansible Core Team"
 '''
 
 EXAMPLES = '''
-- name: Set authorized key took from file
+- name: Set authorized key taken from file
   authorized_key:
     user: charlie
     state: present
     key: "{{ lookup('file', '/home/charlie/.ssh/id_rsa.pub') }}"
 
-- name: Set authorized key took from url
+- name: Set authorized keys taken from url
   authorized_key:
     user: charlie
     state: present
@@ -134,7 +131,7 @@ EXAMPLES = '''
     key: https://github.com/user.keys
     validate_certs: False
 
-- name: Set authorized key, removing all the authorized key already set
+- name: Set authorized key, removing all the authorized keys already set
   authorized_key:
     user: root
     key: '{{ item }}'
@@ -293,7 +290,7 @@ class keydict(dict):
         return [item[1] for item in self.items()]
 
 
-def keyfile(module, user, write=False, path=None, manage_dir=True):
+def keyfile(module, user, write=False, path=None, manage_dir=True, follow=False):
     """
     Calculate name of authorized keys file, optionally creating the
     directories and file, properly setting permissions.
@@ -302,11 +299,16 @@ def keyfile(module, user, write=False, path=None, manage_dir=True):
     :param bool write: if True, write changes to authorized_keys file (creating directories if needed)
     :param str path: if not None, use provided path rather than default of '~user/.ssh/authorized_keys'
     :param bool manage_dir: if True, create and set ownership of the parent dir of the authorized_keys file
+    :param bool follow: if True symlinks will be followed and not replaced
     :return: full path string to authorized_keys for user
     """
 
     if module.check_mode and path is not None:
         keysfile = path
+
+        if follow:
+            return os.path.realpath(keysfile)
+
         return keysfile
 
     try:
@@ -323,6 +325,9 @@ def keyfile(module, user, write=False, path=None, manage_dir=True):
         sshdir = os.path.dirname(path)
         keysfile = path
 
+    if follow:
+        keysfile = os.path.realpath(keysfile)
+
     if not write:
         return keysfile
 
@@ -527,6 +532,7 @@ def enforce_state(module, params):
     key_options = params.get("key_options", None)
     exclusive = params.get("exclusive", False)
     comment = params.get("comment", None)
+    follow = params.get('follow', False)
     error_msg = "Error getting key from: %s"
 
     # if the key is a url, request it and use it as key source
@@ -622,7 +628,7 @@ def enforce_state(module, params):
             do_write = True
 
     if do_write:
-        filename = keyfile(module, user, do_write, path, manage_dir)
+        filename = keyfile(module, user, do_write, path, manage_dir, follow)
         new_content = serialize(existing_keys)
 
         diff = None
@@ -659,6 +665,7 @@ def main():
             exclusive=dict(default=False, type='bool'),
             comment=dict(required=False, default=None, type='str'),
             validate_certs=dict(default=True, type='bool'),
+            follow=dict(default=False, type='bool')
         ),
         supports_check_mode=True
     )
